==> aspbm-1.0.tar.gz: aspbm-1.0/rules.c <==
#include "aspbm.h"  

  /*************/
 /*  Holidays */
/*************/

void hrule(char *string) {

char    *scut=NULL, *sstr=NULL;
char    *p;
int     index = 1;
int     i1,i2,ind = 0;

scut = (void *)malloc(6);
sstr=strdup(string);

while(index == 1) {
        ind = ind +1;

        if (strstr(sstr, ",")) {
                p = strstr(sstr, ",");
                strncpy(scut,sstr,(strlen(sstr)-strlen(p)+1));
                sscanf(scut, "%d/%d,", &i1, &i2);
                hrules[ind].day = i1;
                hrules[ind].month = i2;

                free(scut);
                scut = (void *)malloc(6);

                p += strlen(", ");                             
                sstr=strdup(p);

        }
        else {
                sscanf(sstr, "%d/%d,", &i1, &i2);
                hrules[ind].day = i1;
                hrules[ind].month = i2;
                index = 0;
        }

}
free(scut);
}
                                

  /***************/
 /* Phone Rules */
/***************/

void rule(char *string, int irule) {

int     i1,i2,i3,i4,i5, i7=0;
int     index = 1;
float   i6, i8=0;

/*      fprintf(stderr, "\n%s\n",string);*/
/*      fprintf(stderr, "\n----from %i:%i to %i:%i use %i at %f\n",i1,i2,i3,i4,i5,i6);*/

        sscanf(string, "from %d:%d to %d:%d use %d at %f first %d at %f", &i1, &i2, &i3, &i4, &i5, &i6, &i7, &i8);
        phone_rules[irule].from_h = i1;
        phone_rules[irule].from_m = i2;
        phone_rules[irule].to_h = i3;
        phone_rules[irule].to_m = i4;
        phone_rules[irule].use = i5;
        phone_rules[irule].at = i6;
        if (!i7) i7=0;
        phone_rules[irule].first = i7;
        if (!i8) i8=0;
        phone_rules[irule].fat = i8;

        if (strstr(string, "and")) {
                string = strstr(string, "and");          
                string += strlen("and ");
                phone_rules[irule].and = 1;

        }
        else {
                index=0;
                phone_rules[irule].and = 0;
        }

        while (index == 1) {

                irule=irule + 8;

                sscanf(string, "from %d:%d to %d:%d use %d at %f first %d at %f", &i1, &i2, &i3, &i4, &i5, &i6, &i7, &i8);   
                phone_rules[irule].from_h = i1;
                phone_rules[irule].from_m = i2;
                phone_rules[irule].to_h = i3;
                phone_rules[irule].to_m = i4;                                                        
                phone_rules[irule].use = i5;
                phone_rules[irule].at = i6;
                if (i7==0) i7=0;
                phone_rules[irule].first = i7;
///             if (i8==0) i8=0;
                phone_rules[irule].fat = i8;

                if (strstr(string, "and")) {
                        string = strstr(string, "and");
                        string += strlen("and ");
                        phone_rules[irule].and = 1;
                }
                else {
                        index=0;
                        phone_rules[irule].and = 0;
                }
        }
}

==> aspbm-1.1.tar.gz: aspbm-1.1/rules.c <==
#include "aspbm.h"  

  /*************/
 /*  Holidays */
/*************/

int hrule(char *string) {

char    *scut=NULL, *sstr=NULL;
char    *p;
int     index = 1;
int     i1,i2,ind = 0;
int     maxholi = 0; 

scut = (void *)malloc(6);
sstr=strdup(string);

while(index == 1) {
        ind = ind +1;

        if (strstr(sstr, ",")) {
                p = strstr(sstr, ",");
                strncpy(scut,sstr,(strlen(sstr)-strlen(p)+1));
                sscanf(scut, "%d/%d,", &i1, &i2);
                hrules[ind].day = i1;
                hrules[ind].month = i2;

                free(scut);
                scut = (void *)malloc(6);

                p += strlen(", ");                             
                sstr=strdup(p);

        }
        else {
                sscanf(sstr, "%d/%d,", &i1, &i2);
                hrules[ind].day = i1;
                hrules[ind].month = i2;
                index = 0;
        }
	maxholi = ind;

}
free(scut);
return maxholi;
}
                                

  /***************/
 /* Phone Rules */
/***************/

int rule(char *string, int irule, int max) {

int     i1,i2,i3,i4,i5, i7=0;
int     index = 1;   
float   i6, i8=0;

        sscanf(string, "from %d:%d to %d:%d use %d at %f first %d at %f", &i1, &i2, &i3, &i4, &i5, &i6, &i7, &i8);
        phone_rules[irule].from_h = i1;
        phone_rules[irule].from_m = i2;
        phone_rules[irule].to_h = i3;
        phone_rules[irule].to_m = i4;
        phone_rules[irule].use = i5;
        phone_rules[irule].at = i6;
        if (!i7) i7=0;
        phone_rules[irule].first = i7;
        if (!i8) i8=0;
        phone_rules[irule].fat = i8;

	max=1; 

        if (strstr(string, "and")) {
                string = strstr(string, "and");          
                string += strlen("and ");
                phone_rules[irule].and = 1;

        }
        else {
                index=0;
                phone_rules[irule].and = 0;
        }

        while (index == 1) {

                irule=irule + 8;
		max = max +1; 

                sscanf(string, "from %d:%d to %d:%d use %d at %f first %d at %f", &i1, &i2, &i3, &i4, &i5, &i6, &i7, &i8);   
                phone_rules[irule].from_h = i1;
                phone_rules[irule].from_m = i2;
                phone_rules[irule].to_h = i3;
                phone_rules[irule].to_m = i4;                                                        
                phone_rules[irule].use = i5;
                phone_rules[irule].at = i6;
                if (i7==0) i7=0;
                phone_rules[irule].first = i7;
	     	if (i8==0) i8=0;
                phone_rules[irule].fat = i8;

                if (strstr(string, "and")) {
                        string = strstr(string, "and");
                        string += strlen("and ");
                        phone_rules[irule].and = 1;
                }
                else {
                        index=0;
                        phone_rules[irule].and = 0;
                }
        }
return max;
}
